searchData={"items":[{"type":"module","title":"SpanishDoc","doc":"A module to parse, validate and obfuscate Spanish identity documentation numbers.","ref":"SpanishDoc.html"},{"type":"function","title":"SpanishDoc.obfuscate/1","doc":"Obfuscate a NIF/NIE document number.","ref":"SpanishDoc.html#obfuscate/1"},{"type":"function","title":"Examples - SpanishDoc.obfuscate/1","doc":"iex> SpanishDoc.obfuscate(\"85033335N\")\n    {:ok, :nif, \"***3333**\"}\n\n    iex> SpanishDoc.obfuscate(\"E90725946\")\n    {:ok, :nif, \"***7259**\"}\n\n    iex> SpanishDoc.obfuscate(\"Y7811422S\")\n    {:ok, :nie, \"****1422*\"}\n\n    iex> SpanishDoc.obfuscate(\"hello\")\n    {:error, \"Document not valid\"}","ref":"SpanishDoc.html#obfuscate/1-examples"},{"type":"function","title":"SpanishDoc.parse/1","doc":"Parses a text representation of a NIF/NIE document number.","ref":"SpanishDoc.html#parse/1"},{"type":"function","title":"Examples - SpanishDoc.parse/1","doc":"iex> SpanishDoc.parse(\"16659622D\")\n    {:ok, :nif, \"16659622D\"}\n\n    iex> SpanishDoc.parse(\"M2919200V\")\n    {:ok, :nif, \"M2919200V\"}\n\n    iex> SpanishDoc.parse(\"Q4978527B\")\n    {:ok, :nif, \"Q4978527B\"}\n\n    iex> SpanishDoc.parse(\"y6115461m\")\n    {:ok, :nie, \"Y6115461M\"}\n\n    iex> SpanishDoc.parse(\"16.659.622-D\")\n    {:ok, :nif, \"16659622D\"}\n\n    iex> SpanishDoc.parse(\"16659622Z\")\n    {:error, \"Document not valid\"}\n\n    iex> SpanishDoc.parse(\"123456789\")\n    {:error, \"Document not valid\"}\n\n    iex> SpanishDoc.parse(\"1234\")\n    {:error, \"Document not valid\"}\n\n    iex> SpanishDoc.parse(\"hello\")\n    {:error, \"Document not valid\"}","ref":"SpanishDoc.html#parse/1-examples"},{"type":"function","title":"SpanishDoc.valid?/1","doc":"Checks the NIF/NIE document number has a valid NIF/NIE format.","ref":"SpanishDoc.html#valid?/1"},{"type":"function","title":"Examples - SpanishDoc.valid?/1","doc":"iex> SpanishDoc.valid?(\"16659622D\")\n    true\n\n    iex> SpanishDoc.valid?(\"16659622X\")\n    false\n\n    iex> SpanishDoc.valid?(\"error\")\n    false","ref":"SpanishDoc.html#valid?/1-examples"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v1.3.0 (2024-05-01) - Changelog","doc":"* The use of lowercase letters is allowed.","ref":"changelog.html#v1-3-0-2024-05-01"},{"type":"extras","title":"v1.2.0 (2023-12-20) - Changelog","doc":"* Refactoring and improvement of documentation.","ref":"changelog.html#v1-2-0-2023-12-20"},{"type":"extras","title":"v1.1.0 (2023-12-18) - Changelog","doc":"* The functions `SpanishDoc.parse/1` and `SpanishDoc.obfuscate/1` now return a\ntuple with the document type:\n\n```elixir\nSpanishDoc.parse(\"Y6115461M\")\n{:ok, :nie, \"Y6115461M\"}\n\nSpanishDoc.obfuscate(\"85033335N\")\n{:ok, :nif, \"***3333**\"}\n```\n\n* Added this `CHANGELOG.md` file to keep track of the changes.","ref":"changelog.html#v1-1-0-2023-12-18"},{"type":"extras","title":"v1.0.0 (2023-12-17) - Changelog","doc":"* This is the first production ready release.","ref":"changelog.html#v1-0-0-2023-12-17"},{"type":"extras","title":"Introduction","doc":"# Introduction\n\n**SpanishDoc** is a library to parse Spanish identity documentation numbers like:\n\n  * NIF: _Número de Identificación Fiscal._\n  * NIE: _Número de Identificación de Extranjeros._","ref":"readme.html"},{"type":"extras","title":"Installation - Introduction","doc":"Add `spanish_doc` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:spanish_doc, \"~> 1.3.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Introduction","doc":"```elixir\nSpanishDoc.valid?(\"16659622D\")\ntrue\n\nSpanishDoc.parse(\"16.659.622-D\")\n{:ok, :nif, \"16659622D\"}\n\nSpanishDoc.obfuscate(\"E90725946\")\n{:ok, :nif, \"***7259**\"}\n```","ref":"readme.html#usage"}],"content_type":"text/markdown"}